inferpy.models package
======================

Submodules
----------

inferpy.models.parameter module
-------------------------------

.. automodule:: inferpy.models.parameter
   :members:
   :undoc-members:
   :show-inheritance:

inferpy.models.prob\_model module
---------------------------------

.. automodule:: inferpy.models.prob_model
   :members:
   :undoc-members:
   :show-inheritance:

inferpy.models.random\_variable module
--------------------------------------

.. automodule:: inferpy.models.random_variable
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: inferpy.models
   :members:
   :undoc-members:
   :show-inheritance:
